"use strict";
/**
 * A set of async RPC calls which substitute the sync calls made by the core reporter
 * These allow us to use BuidlerEVM or another in-process provider.
 */
Object.defineProperty(exports, "__esModule", { value: true });
class AsyncProvider {
    constructor(provider) {
        this.provider = provider;
    }
    async getNetworkId() {
        return this.provider.send("net_version", []);
    }
    async getCode(address) {
        return this.provider.send("eth_getCode", [address, "latest"]);
    }
    async getLatestBlock() {
        return this.provider.send("eth_getBlockByNumber", ["latest", false]);
    }
    async getBlockByNumber(num) {
        const hexNumber = `0x${num.toString(16)}`;
        return this.provider.send("eth_getBlockByNumber", [hexNumber, true]);
    }
    async blockNumber() {
        const block = await this.getLatestBlock();
        return parseInt(block.number, 16);
    }
    async getTransactionByHash(tx) {
        return this.provider.send("eth_getTransactionByHash", [tx]);
    }
    async call(payload, blockNumber) {
        return this.provider.send("eth_call", [payload, blockNumber]);
    }
}
exports.default = AsyncProvider;
//# sourceMappingURL=provider.js.map